# .context/ Artifacts

Living documentation for the KnowledgeLM codebase.

## Artifacts

| File | Purpose | Update When |
|------|---------|-------------|
| [OVERVIEW.md](OVERVIEW.md) | Project scope and purpose | Dependencies, features change |
| [ARCHITECTURE.md](ARCHITECTURE.md) | Module structure and data flow | Structure changes |
| [CONVENTIONS.md](CONVENTIONS.md) | Code patterns and standards | New patterns established |
| [DESIGN.md](DESIGN.md) | Feature status tracking | Features added/completed |
| [CHANGELOG.md](CHANGELOG.md) | Released changes | Any meaningful change |

## Status Markers (DESIGN.md)

```
[idea]         — Concept only
[designing]    — Being planned
[implementing] — In progress
[done]         — Complete
```
